@@ -3,7 +3,6 @@ use strict;
 use utf8;
 
 use WebService::Technorati::ApiQuery;
-use WebService::Technorati::BlogSubject;
 use WebService::Technorati::BlogLink;
 use WebService::Technorati::Exception;
 use base 'WebService::Technorati::ApiQuery';
@@ -11,45 +10,46 @@ use base 'WebService::Technorati::ApiQuery';
 use constant API_URI => '/cosmos';
 
 BEGIN {
-	use vars qw ($VERSION);
-	$VERSION     = 0.02;
+    use vars qw ($VERSION $DEBUG);
+    $VERSION     = 0.03;
+    $DEBUG       = 0;
 }
 
 sub new {
-	my ($class, %params) = @_;
-	if (! exists $params{'key'}) {
-		WebService::Technorati::InstantiationException->throw(
-		  "WebService::Technorati::BloginfoApiQuery must be " .
-		  "instantiated with at least 'key => theverylongkeystring'");	
+    my ($class, %params) = @_;
+    if (! exists $params{'key'}) {
+    WebService::Technorati::InstantiationException->throw(
+        "WebService::Technorati::BloginfoApiQuery must be " .
+        "instantiated with at least 'key => theverylongkeystring'");
     }
-	my $data = {};
-	if (! exists $params{'url'}) {
-		$data->{'needs_url'}++;
-	}
-	for my $k (keys %params) {
-	     $data->{'args'}{$k} = $params{$k};
-	}
-	my $self = bless ($data, ref ($class) || $class);
-	return $self;
+    my $data = {};
+    if (! exists $params{'url'}) {
+        $data->{'needs_url'}++;
+    }
+    for my $k (keys %params) {
+        $data->{'args'}{$k} = $params{$k};
+    }
+    my $self = bless ($data, ref ($class) || $class);
+    return $self;
 }
 
 sub url {
-	my $self = shift;
-	my $url = shift;
-	if ($url) {
-	    $self->{'url'} = $url;
-	    delete($self->{'needs_url'});
-	}
-	return $self->{'url'};
+    my $self = shift;
+    my $url = shift;
+    if ($url) {
+        $self->{'url'} = $url;
+        delete($self->{'needs_url'});
+    }
+    return $self->{'url'};
 }
 
 sub execute {
     my $self = shift;
     my $apiUrl = $self->apiHostUrl() . API_URI;
     if (exists $self->{'needs_url'}) {
-    		WebService::Technorati::StateValidationException->throw(
-    		"WebService::Technorati::AuthorinfoApiQuery must have a " .
-    		"'url' attribute set prior to query execution");
+        WebService::Technorati::StateValidationException->throw(
+            "WebService::Technorati::AuthorinfoApiQuery must have a " .
+            "'url' attribute set prior to query execution");
     }
     $self->SUPER::execute($apiUrl,$self->{'args'});  
 }
@@ -59,12 +59,12 @@ sub readResults {
     my $result_xp = shift;
     my $error = $result_xp->find('/tapi/document/result/error');
     if ($error) {
-    		WebService::Technorati::DataException->throw($error);
+        WebService::Technorati::DataException->throw($error);
     }
     my $nodeset = $result_xp->find("/tapi/document/result/weblog");
     my $node = $nodeset->shift;
-	my $blog = WebService::Technorati::Blog->new_from_node($node);
-	
+    my $blog = WebService::Technorati::Blog->new_from_node($node);
+    
     $self->{'blog'} = $blog;
 }
 
@@ -87,4 +87,4 @@ sub getSubjectBlog {
     return $self->{'blog'};
 }
 
-1;
\ No newline at end of file
+1;
